==> haskell-shellmet-0.0.5.0-98.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-shellmet.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 shellmet
version:              0.0.5.0
visibility:           public
id:                   shellmet-0.0.5.0-LX10n1Zi5evJZ1HpFqeuzN
key:                  shellmet-0.0.5.0-LX10n1Zi5evJZ1HpFqeuzN
license:              MPL-2.0
copyright:            2019-2022 Kowainik
maintainer:           Kowainik <xrom.xkov@gmail.com>
author:               Dmitrii Kovanikov
homepage:             https://github.com/kowainik/shellmet
synopsis:             Out of the shell solution for scripting in Haskell
description:
    Shellmet provides easy and convenient way to call shell commands from Haskell programs

category:             Shell, Command Line
abi:                  e562320efd098e52bf3c372ea7762f27
exposed:              True
exposed-modules:      Shellmet
import-dirs:          /usr/lib/ghc-9.6.6/site-local/shellmet-0.0.5.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/shellmet-0.0.5.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/shellmet-0.0.5.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-shellmet
hs-libraries:         HSshellmet-0.0.5.0-LX10n1Zi5evJZ1HpFqeuzN
depends:              base-4.18.2.1 process-1.6.19.0 text-2.0.2
haddock-interfaces:   /usr/share/doc/haskell-shellmet/html/shellmet.haddock
haddock-html:         /usr/share/doc/haskell-shellmet/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-shellmet-0.0.5.0-99-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-shellmet.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 shellmet
version:              0.0.5.0
visibility:           public
id:                   shellmet-0.0.5.0-5wFljDtiwo8MIHgU4BEvA
key:                  shellmet-0.0.5.0-5wFljDtiwo8MIHgU4BEvA
license:              MPL-2.0
copyright:            2019-2022 Kowainik
maintainer:           Kowainik <xrom.xkov@gmail.com>
author:               Dmitrii Kovanikov
homepage:             https://github.com/kowainik/shellmet
synopsis:             Out of the shell solution for scripting in Haskell
description:
    Shellmet provides easy and convenient way to call shell commands from Haskell programs

category:             Shell, Command Line
abi:                  cad6a410fa40f658fad9b05a95971561
exposed:              True
exposed-modules:      Shellmet
import-dirs:          /usr/lib/ghc-9.6.6/site-local/shellmet-0.0.5.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/shellmet-0.0.5.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/shellmet-0.0.5.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-shellmet
hs-libraries:         HSshellmet-0.0.5.0-5wFljDtiwo8MIHgU4BEvA
depends:              base-4.18.2.1 process-1.6.19.0 text-2.0.2
haddock-interfaces:   /usr/share/doc/haskell-shellmet/html/shellmet.haddock
haddock-html:         /usr/share/doc/haskell-shellmet/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
